import type { RGB } from "@siteimprove/alfa-css";
import type { Node } from "@siteimprove/alfa-dom";
import type { Option } from "@siteimprove/alfa-option";
import * as act from "@siteimprove/alfa-act";
/**
 * @public
 */
export declare namespace Question {
    /**
     * Maps the `type` parameter of questions to the expected type of the answer.
     */
    interface Type {
        boolean: boolean;
        node: Option<Node>;
        "node[]": Iterable<Node>;
        "color[]": Iterable<RGB>;
        string: string;
    }
    type TypeName<U extends Uri> = Data[U]["type"];
    type Typeof<U extends Uri> = Type[TypeName<U>];
    /**
     * @public
     * Maps the `uri` parameter of questions to their `type` parameter and the
     * expected type of answers.
     */
    export type Metadata = {
        [U in Uri]: [TypeName<U>, Typeof<U>];
    };
    type Data = typeof Data & Record<Uri, {
        readonly type: keyof Type;
        readonly message: string;
    }>;
    type Uri = keyof typeof Data;
    export function of<S, U extends Uri = Uri>(uri: U, subject: S, message?: string, options?: act.Question.Options<Typeof<U>>): act.Question<TypeName<U>, S, S, Typeof<U>, Typeof<U>, U>;
    export function of<S, C, U extends Uri = Uri>(uri: U, subject: S, context: C, message?: string, options?: act.Question.Options<Typeof<U>>): act.Question<TypeName<U>, S, C, Typeof<U>, Typeof<U>, U>;
    const Data: {
        readonly "reference-equivalent-resources": {
            readonly type: "boolean";
            readonly message: "Do the [links/iframe] [resolve to/reference] equivalent resources?";
        };
        readonly "has-audio": {
            readonly type: "boolean";
            readonly message: "Does the `<video>` element have audio?";
        };
        readonly "has-audio-track": {
            readonly type: "boolean";
            readonly message: "Does the `<video>` element have an audio track that describes its visual information?";
        };
        readonly "has-captions": {
            readonly type: "boolean";
            readonly message: "Does the `<video>` element have captions that describe the content of the video?";
        };
        readonly "has-description": {
            readonly type: "boolean";
            readonly message: "Is the visual information of the [audio/video] available through its audio or a separate audio description track?";
        };
        readonly "is-audio-streaming": {
            readonly type: "boolean";
            readonly message: "Is the `<audio>` element streaming?";
        };
        readonly "is-playing": {
            readonly type: "boolean";
            readonly message: "Is the `<audio>` element currently playing?";
        };
        readonly "is-video-streaming": {
            readonly type: "boolean";
            readonly message: "Is the `<video>` element streaming?";
        };
        readonly label: {
            readonly type: "node";
            readonly message: "Where is the text that labels the [audio/video] element as a video alternative?";
        };
        readonly "play-button": {
            readonly type: "node";
            readonly message: "Where is the button that controls playback of the `<audio>` element?";
        };
        readonly "text-alternative": {
            readonly type: "node";
            readonly message: "Where is the text alternative of the [audio/video] element?";
        };
        readonly "track-describes-video": {
            readonly type: "boolean";
            readonly message: "Does at least 1 track describe the visual information of the `<video>` element, either in the language of the `<video>` element or the language of the page?";
        };
        readonly transcript: {
            readonly type: "node";
            readonly message: "Where is the transcript that describes the content of the [audio/video] element?";
        };
        readonly "transcript-link": {
            readonly type: "node";
            readonly message: "Where is the link pointing to the transcript that describes the content of the [audio/video] element?";
        };
        readonly "name-describes-purpose": {
            readonly type: "boolean";
            readonly message: "Does the accessible name of the `<(target.name]>` element describe its purpose?";
        };
        readonly "audio-control-mechanism": {
            readonly type: "node";
            readonly message: "Where is the mechanism that can pause or stop the audio of the `<[target.name]>` element?";
        };
        readonly "is-above-duration-threshold": {
            readonly type: "boolean";
            readonly message: "Does the `<[element.name]>` element have a duration of more than 3 seconds?";
        };
        readonly "is-below-audio-duration-threshold": {
            readonly type: "boolean";
            readonly message: "Does the `<[target.name]>` element have a total audio duration of less than 3 seconds?";
        };
        readonly "is-content-equivalent": {
            readonly type: "boolean";
            readonly message: "Do these [role] landmarks have the same or equivalent content?";
        };
        readonly "has-focus-indicator": {
            readonly type: "boolean";
            readonly message: "Does the element have a visible focus indicator?";
        };
        readonly "background-colors": {
            readonly type: "color[]";
            readonly message: "What are the background colors of the text node?";
        };
        readonly "foreground-colors": {
            readonly type: "color[]";
            readonly message: "What are the foreground colors of the text node?";
        };
        readonly "ignored-interposed-elements": {
            readonly type: "node[]";
            readonly message: "Which of these interposed descendants should be ignored?";
        };
        readonly "first-tabbable-is-internal-link": {
            readonly type: "boolean";
            readonly message: "Is the first tabbable element of the document an internal link?";
        };
        readonly "first-tabbable-is-visible": {
            readonly type: "boolean";
            readonly message: "Is the first tabbable element of the document visible if it's focused?";
        };
        readonly "first-tabbable-reference": {
            readonly type: "node";
            readonly message: "Where in the document does the first tabbable element point?";
        };
        readonly "first-tabbable-reference-is-main": {
            readonly type: "boolean";
            readonly message: "Does the first tabbable element of the document point to the main content?";
        };
        readonly "error-indicators": {
            readonly type: "node[]";
            readonly message: "Where are (all) the error indicators, if any, for the form field?";
        };
        readonly "error-indicator-describing-resolution": {
            readonly type: "node";
            readonly message: "Which of these error indicators describes, in text, the cause of the error or how to resolve it?";
        };
        readonly "error-indicator-identifying-form-field": {
            readonly type: "node";
            readonly message: "Which of these error indicators identifies, in text, the form field it relates to?";
        };
        readonly "internal-reference": {
            readonly type: "node";
            readonly message: "Where in the document does this element point?";
        };
        readonly "is-start-of-main": {
            readonly type: "boolean";
            readonly message: "Is this element at the start of the main content of the document?";
        };
        readonly "is-visible-when-focused": {
            readonly type: "boolean";
            readonly message: "Is this element visible when it's focused?";
        };
        readonly "document-language": {
            readonly type: "string";
            readonly message: "What is the main language of the document?";
        };
        readonly "is-title-descriptive": {
            readonly type: "boolean";
            readonly message: "Does this title describe the content of the document?";
        };
    };
    export {};
}
//# sourceMappingURL=question.d.ts.map